@@ -42,6 +42,12 @@ def _iterate_timeout(timeout, message, wait=2):
     log = _log.setup_logging(__name__)
 
     try:
+        # None as a wait winds up flowing well in the per-resource cache
+        # flow. We could spread this logic around to all of the calling
+        # points, but just having this treat None as "I don't have a value"
+        # seems friendlier
+        if wait is None:
+            wait = 2
         wait = float(wait)
     except ValueError:
         raise exc.OpenStackCloudException(
@@ -323,7 +329,7 @@ def normalize_neutron_floating_ips(ips):
             router_id=ip.get('router_id'),
             attached=(ip.get('port_id') is not None and
                       ip.get('port_id') != ''),
-            status=ip['status'],
+            status=ip.get('status', 'UNKNOWN')
         ))
     return meta.obj_list_to_dict(ret)
 
@@ -526,16 +532,19 @@ def valid_kwargs(*valid_args):
 
 
 def cache_on_arguments(*cache_on_args, **cache_on_kwargs):
+    _cache_name = cache_on_kwargs.pop('resource', None)
+
     def _inner_cache_on_arguments(func):
         def _cache_decorator(obj, *args, **kwargs):
-            the_method = obj._cache.cache_on_arguments(
+            the_method = obj._get_cache(_cache_name).cache_on_arguments(
                 *cache_on_args, **cache_on_kwargs)(
                     func.__get__(obj, type(obj)))
             return the_method(*args, **kwargs)
 
         def invalidate(obj, *args, **kwargs):
-            return obj._cache.cache_on_arguments()(func).invalidate(
-                *args, **kwargs)
+            return obj._get_cache(
+                _cache_name).cache_on_arguments()(func).invalidate(
+                    *args, **kwargs)
 
         _cache_decorator.invalidate = invalidate
         _cache_decorator.func = func
