@@ -288,9 +288,7 @@ class TestMemoryCache(base.TestCase):
         mock_compute.get.return_value = mock_response
         self.assertEqual([], self.cloud.list_flavors())
 
-        fake_flavor = fakes.FakeFlavor(
-            '555', 'vanilla', 100, dict(
-                x_openstack_request_ids=['request-id']))
+        fake_flavor = fakes.FakeFlavor('555', 'vanilla', 100)
         fake_flavor_dict = _utils.normalize_flavors(
             [meta.obj_to_dict(fake_flavor)]
         )[0]
@@ -348,7 +346,8 @@ class TestMemoryCache(base.TestCase):
         imagefile.write(b'\0')
         imagefile.close()
         self.cloud.create_image(
-            name, imagefile.name, wait=True, is_public=False, **kwargs)
+            name, imagefile.name, wait=True, timeout=1,
+            is_public=False, **kwargs)
 
     @mock.patch.object(occ.cloud_config.CloudConfig, 'get_api_version')
     @mock.patch.object(shade.OpenStackCloud, 'glance_client')
