@@ -61,6 +61,18 @@ class FakeCloud(object):
     def get_external_networks(self):
         return []
 
+    def get_internal_ipv4_networks(self):
+        return []
+
+    def get_external_ipv4_networks(self):
+        return []
+
+    def get_internal_ipv6_networks(self):
+        return []
+
+    def get_external_ipv6_networks(self):
+        return []
+
     def list_server_security_groups(self, server):
         return []
 
@@ -107,6 +119,116 @@ SUBNETS_WITH_NAT = [
     },
 ]
 
+OSIC_NETWORKS = [
+    {
+        u'admin_state_up': True,
+        u'id': u'7004a83a-13d3-4dcd-8cf5-52af1ace4cae',
+        u'mtu': 0,
+        u'name': u'GATEWAY_NET',
+        u'router:external': True,
+        u'shared': True,
+        u'status': u'ACTIVE',
+        u'subnets': [u'cf785ee0-6cc9-4712-be3d-0bf6c86cf455'],
+        u'tenant_id': u'7a1ca9f7cc4e4b13ac0ed2957f1e8c32'
+    },
+    {
+        u'admin_state_up': True,
+        u'id': u'405abfcc-77dc-49b2-a271-139619ac9b26',
+        u'mtu': 0,
+        u'name': u'openstackjenkins-network1',
+        u'router:external': False,
+        u'shared': False,
+        u'status': u'ACTIVE',
+        u'subnets': [u'a47910bc-f649-45db-98ec-e2421c413f4e'],
+        u'tenant_id': u'7e9c4d5842b3451d94417bd0af03a0f4'
+    },
+    {
+        u'admin_state_up': True,
+        u'id': u'54753d2c-0a58-4928-9b32-084c59dd20a6',
+        u'mtu': 0,
+        u'name': u'GATEWAY_NET_V6',
+        u'router:external': True,
+        u'shared': True,
+        u'status': u'ACTIVE',
+        u'subnets': [u'9c21d704-a8b9-409a-b56d-501cb518d380',
+                     u'7cb0ce07-64c3-4a3d-92d3-6f11419b45b9'],
+        u'tenant_id': u'7a1ca9f7cc4e4b13ac0ed2957f1e8c32'
+    }
+]
+
+OSIC_SUBNETS = [
+    {
+        u'allocation_pools': [{
+            u'end': u'172.99.106.254',
+            u'start': u'172.99.106.5'}],
+        u'cidr': u'172.99.106.0/24',
+        u'dns_nameservers': [u'69.20.0.164', u'69.20.0.196'],
+        u'enable_dhcp': True,
+        u'gateway_ip': u'172.99.106.1',
+        u'host_routes': [],
+        u'id': u'cf785ee0-6cc9-4712-be3d-0bf6c86cf455',
+        u'ip_version': 4,
+        u'ipv6_address_mode': None,
+        u'ipv6_ra_mode': None,
+        u'name': u'GATEWAY_NET',
+        u'network_id': u'7004a83a-13d3-4dcd-8cf5-52af1ace4cae',
+        u'subnetpool_id': None,
+        u'tenant_id': u'7a1ca9f7cc4e4b13ac0ed2957f1e8c32'
+    },
+    {
+        u'allocation_pools': [{
+            u'end': u'10.0.1.254', u'start': u'10.0.1.2'}],
+        u'cidr': u'10.0.1.0/24',
+        u'dns_nameservers': [u'8.8.8.8', u'8.8.4.4'],
+        u'enable_dhcp': True,
+        u'gateway_ip': u'10.0.1.1',
+        u'host_routes': [],
+        u'id': u'a47910bc-f649-45db-98ec-e2421c413f4e',
+        u'ip_version': 4,
+        u'ipv6_address_mode': None,
+        u'ipv6_ra_mode': None,
+        u'name': u'openstackjenkins-subnet1',
+        u'network_id': u'405abfcc-77dc-49b2-a271-139619ac9b26',
+        u'subnetpool_id': None,
+        u'tenant_id': u'7e9c4d5842b3451d94417bd0af03a0f4'
+    },
+    {
+        u'allocation_pools': [{
+            u'end': u'10.255.255.254', u'start': u'10.0.0.2'}],
+        u'cidr': u'10.0.0.0/8',
+        u'dns_nameservers': [u'8.8.8.8', u'8.8.4.4'],
+        u'enable_dhcp': True,
+        u'gateway_ip': u'10.0.0.1',
+        u'host_routes': [],
+        u'id': u'9c21d704-a8b9-409a-b56d-501cb518d380',
+        u'ip_version': 4,
+        u'ipv6_address_mode': None,
+        u'ipv6_ra_mode': None,
+        u'name': u'GATEWAY_SUBNET_V6V4',
+        u'network_id': u'54753d2c-0a58-4928-9b32-084c59dd20a6',
+        u'subnetpool_id': None,
+        u'tenant_id': u'7a1ca9f7cc4e4b13ac0ed2957f1e8c32'
+    },
+    {
+        u'allocation_pools': [{
+            u'end': u'2001:4800:1ae1:18:ffff:ffff:ffff:ffff',
+            u'start': u'2001:4800:1ae1:18::2'}],
+        u'cidr': u'2001:4800:1ae1:18::/64',
+        u'dns_nameservers': [u'2001:4860:4860::8888'],
+        u'enable_dhcp': True,
+        u'gateway_ip': u'2001:4800:1ae1:18::1',
+        u'host_routes': [],
+        u'id': u'7cb0ce07-64c3-4a3d-92d3-6f11419b45b9',
+        u'ip_version': 6,
+        u'ipv6_address_mode': u'dhcpv6-stateless',
+        u'ipv6_ra_mode': None,
+        u'name': u'GATEWAY_SUBNET_V6V6',
+        u'network_id': u'54753d2c-0a58-4928-9b32-084c59dd20a6',
+        u'subnetpool_id': None,
+        u'tenant_id': u'7a1ca9f7cc4e4b13ac0ed2957f1e8c32'
+    }
+]
+
 
 class TestMeta(base.TestCase):
     def test_find_nova_addresses_key_name(self):
@@ -250,7 +372,7 @@ class TestMeta(base.TestCase):
             mock_list_server_security_groups,
             mock_list_subnets,
             mock_list_floating_ips):
-        self.cloud._floating_ip_source = 'none'
+        self.cloud._floating_ip_source = None
         mock_get_image_name.return_value = 'cirros-0.3.4-x86_64-uec'
         mock_get_flavor_name.return_value = 'm1.tiny'
         mock_has_service.return_value = True
@@ -278,8 +400,7 @@ class TestMeta(base.TestCase):
                 u'OS-EXT-IPS:type': u'fixed',
                 u'addr': PRIVATE_V4,
                 u'version': 4,
-                u'OS-EXT-IPS-MAC:mac_addr':
-                u'fa:16:3e:ae:7d:42'
+                u'OS-EXT-IPS-MAC:mac_addr': u'fa:16:3e:ae:7d:42'
             }]}
         )))
 
@@ -288,6 +409,162 @@ class TestMeta(base.TestCase):
         mock_list_networks.assert_called_once_with()
         mock_list_floating_ips.assert_not_called()
 
+    @mock.patch.object(shade.OpenStackCloud, 'list_floating_ips')
+    @mock.patch.object(shade.OpenStackCloud, 'list_subnets')
+    @mock.patch.object(shade.OpenStackCloud, 'list_server_security_groups')
+    @mock.patch.object(shade.OpenStackCloud, 'get_volumes')
+    @mock.patch.object(shade.OpenStackCloud, 'get_image_name')
+    @mock.patch.object(shade.OpenStackCloud, 'get_flavor_name')
+    @mock.patch.object(shade.OpenStackCloud, 'has_service')
+    @mock.patch.object(shade.OpenStackCloud, 'list_networks')
+    def test_get_server_cloud_no_fips(
+            self, mock_list_networks, mock_has_service,
+            mock_get_flavor_name, mock_get_image_name,
+            mock_get_volumes,
+            mock_list_server_security_groups,
+            mock_list_subnets,
+            mock_list_floating_ips):
+        self.cloud._floating_ip_source = None
+        mock_get_image_name.return_value = 'cirros-0.3.4-x86_64-uec'
+        mock_get_flavor_name.return_value = 'm1.tiny'
+        mock_has_service.return_value = True
+        mock_get_volumes.return_value = []
+        mock_list_subnets.return_value = SUBNETS_WITH_NAT
+        mock_list_networks.return_value = [
+            {
+                'id': 'test_pnztt_net',
+                'name': 'test_pnztt_net',
+                'router:external': False,
+            },
+            {
+                'id': 'private',
+                'name': 'private',
+            },
+        ]
+
+        srv = self.cloud.get_openstack_vars(meta.obj_to_dict(fakes.FakeServer(
+            id='test-id', name='test-name', status='ACTIVE',
+            flavor={u'id': u'1'},
+            image={
+                'name': u'cirros-0.3.4-x86_64-uec',
+                u'id': u'f93d000b-7c29-4489-b375-3641a1758fe1'},
+            addresses={u'test_pnztt_net': [{
+                u'addr': PRIVATE_V4,
+                u'version': 4,
+            }]}
+        )))
+
+        self.assertEqual(PRIVATE_V4, srv['private_v4'])
+        mock_has_service.assert_called_with('volume')
+        mock_list_networks.assert_called_once_with()
+        mock_list_floating_ips.assert_not_called()
+
+    @mock.patch.object(shade.OpenStackCloud, 'list_floating_ips')
+    @mock.patch.object(shade.OpenStackCloud, 'list_subnets')
+    @mock.patch.object(shade.OpenStackCloud, 'list_server_security_groups')
+    @mock.patch.object(shade.OpenStackCloud, 'get_image_name')
+    @mock.patch.object(shade.OpenStackCloud, 'get_flavor_name')
+    @mock.patch.object(shade.OpenStackCloud, 'has_service')
+    @mock.patch.object(shade.OpenStackCloud, 'list_networks')
+    def test_get_server_cloud_rackspace_v6(
+            self, mock_list_networks, mock_has_service,
+            mock_get_flavor_name, mock_get_image_name,
+            mock_list_server_security_groups,
+            mock_list_subnets,
+            mock_list_floating_ips):
+        self.cloud._floating_ip_source = None
+        self.cloud.force_ipv4 = False
+        self.cloud._local_ipv6 = True
+        mock_get_image_name.return_value = 'cirros-0.3.4-x86_64-uec'
+        mock_get_flavor_name.return_value = 'm1.tiny'
+        mock_has_service.return_value = False
+
+        srv = self.cloud.get_openstack_vars(meta.obj_to_dict(fakes.FakeServer(
+            id='test-id', name='test-name', status='ACTIVE',
+            flavor={u'id': u'1'},
+            image={
+                'name': u'cirros-0.3.4-x86_64-uec',
+                u'id': u'f93d000b-7c29-4489-b375-3641a1758fe1'},
+            addresses={
+                'private': [{
+                    'addr': "10.223.160.141",
+                    'version': 4
+                }],
+                'public': [{
+                    'addr': "104.130.246.91",
+                    'version': 4
+                }, {
+                    'addr': "2001:4800:7819:103:be76:4eff:fe05:8525",
+                    'version': 6
+                }]
+            }
+        )))
+
+        self.assertEqual("10.223.160.141", srv['private_v4'])
+        self.assertEqual("104.130.246.91", srv['public_v4'])
+        self.assertEqual(
+            "2001:4800:7819:103:be76:4eff:fe05:8525", srv['public_v6'])
+        self.assertEqual(
+            "2001:4800:7819:103:be76:4eff:fe05:8525", srv['interface_ip'])
+        mock_list_subnets.assert_not_called()
+        mock_list_networks.assert_not_called()
+        mock_list_floating_ips.assert_not_called()
+
+    @mock.patch.object(shade.OpenStackCloud, 'list_floating_ips')
+    @mock.patch.object(shade.OpenStackCloud, 'list_subnets')
+    @mock.patch.object(shade.OpenStackCloud, 'list_server_security_groups')
+    @mock.patch.object(shade.OpenStackCloud, 'get_image_name')
+    @mock.patch.object(shade.OpenStackCloud, 'get_flavor_name')
+    @mock.patch.object(shade.OpenStackCloud, 'has_service')
+    @mock.patch.object(shade.OpenStackCloud, 'list_networks')
+    def test_get_server_cloud_osic_split(
+            self, mock_list_networks, mock_has_service,
+            mock_get_flavor_name, mock_get_image_name,
+            mock_list_server_security_groups,
+            mock_list_subnets,
+            mock_list_floating_ips):
+        self.cloud._floating_ip_source = None
+        self.cloud.force_ipv4 = False
+        self.cloud._local_ipv6 = True
+        self.cloud._external_ipv4_names = ['GATEWAY_NET']
+        self.cloud._external_ipv6_names = ['GATEWAY_NET_V6']
+        self.cloud._internal_ipv4_names = ['GATEWAY_NET_V6']
+        self.cloud._internal_ipv6_names = []
+        mock_get_image_name.return_value = 'cirros-0.3.4-x86_64-uec'
+        mock_get_flavor_name.return_value = 'm1.tiny'
+        mock_has_service.return_value = True
+        mock_list_subnets.return_value = OSIC_SUBNETS
+        mock_list_networks.return_value = OSIC_NETWORKS
+
+        srv = self.cloud.get_openstack_vars(meta.obj_to_dict(fakes.FakeServer(
+            id='test-id', name='test-name', status='ACTIVE',
+            flavor={u'id': u'1'},
+            image={
+                'name': u'cirros-0.3.4-x86_64-uec',
+                u'id': u'f93d000b-7c29-4489-b375-3641a1758fe1'},
+            addresses={
+                'private': [{
+                    'addr': "10.223.160.141",
+                    'version': 4
+                }],
+                'public': [{
+                    'addr': "104.130.246.91",
+                    'version': 4
+                }, {
+                    'addr': "2001:4800:7819:103:be76:4eff:fe05:8525",
+                    'version': 6
+                }]
+            }
+        )))
+
+        self.assertEqual("10.223.160.141", srv['private_v4'])
+        self.assertEqual("104.130.246.91", srv['public_v4'])
+        self.assertEqual(
+            "2001:4800:7819:103:be76:4eff:fe05:8525", srv['public_v6'])
+        self.assertEqual(
+            "2001:4800:7819:103:be76:4eff:fe05:8525", srv['interface_ip'])
+        mock_list_floating_ips.assert_not_called()
+
     @mock.patch.object(shade.OpenStackCloud, 'has_service')
     @mock.patch.object(shade.OpenStackCloud, 'list_subnets')
     @mock.patch.object(shade.OpenStackCloud, 'list_networks')
@@ -543,19 +820,19 @@ class TestMeta(base.TestCase):
         self.assertEqual(PUBLIC_V4, hostvars['public_v4'])
         self.assertEqual(PUBLIC_V6, hostvars['public_v6'])
         self.assertEqual(PUBLIC_V6, hostvars['interface_ip'])
-        self.assertEquals('REGION_NAME', hostvars['region'])
-        self.assertEquals('CLOUD_NAME', hostvars['cloud'])
-        self.assertEquals("test-image-name", hostvars['image']['name'])
-        self.assertEquals(standard_fake_server.image['id'],
-                          hostvars['image']['id'])
+        self.assertEqual('REGION_NAME', hostvars['region'])
+        self.assertEqual('CLOUD_NAME', hostvars['cloud'])
+        self.assertEqual("test-image-name", hostvars['image']['name'])
+        self.assertEqual(
+            standard_fake_server.image['id'], hostvars['image']['id'])
         self.assertNotIn('links', hostvars['image'])
-        self.assertEquals(standard_fake_server.flavor['id'],
-                          hostvars['flavor']['id'])
-        self.assertEquals("test-flavor-name", hostvars['flavor']['name'])
+        self.assertEqual(
+            standard_fake_server.flavor['id'], hostvars['flavor']['id'])
+        self.assertEqual("test-flavor-name", hostvars['flavor']['name'])
         self.assertNotIn('links', hostvars['flavor'])
         # test having volumes
         # test volume exception
-        self.assertEquals([], hostvars['volumes'])
+        self.assertEqual([], hostvars['volumes'])
 
     @mock.patch.object(shade.meta, 'get_server_external_ipv6')
     @mock.patch.object(shade.meta, 'get_server_external_ipv4')
@@ -589,7 +866,7 @@ class TestMeta(base.TestCase):
         server.image = 'fake-image-id'
         hostvars = meta.get_hostvars_from_server(
             FakeCloud(), meta.obj_to_dict(server))
-        self.assertEquals('fake-image-id', hostvars['image']['id'])
+        self.assertEqual('fake-image-id', hostvars['image']['id'])
 
     def test_az(self):
         server = standard_fake_server
@@ -598,7 +875,7 @@ class TestMeta(base.TestCase):
         hostvars = _utils.normalize_server(
             meta.obj_to_dict(server),
             cloud_name='', region_name='')
-        self.assertEquals('az1', hostvars['az'])
+        self.assertEqual('az1', hostvars['az'])
 
     def test_has_volume(self):
         mock_cloud = mock.MagicMock()
@@ -612,15 +889,15 @@ class TestMeta(base.TestCase):
         mock_cloud.get_volumes.return_value = [fake_volume_dict]
         hostvars = meta.get_hostvars_from_server(
             mock_cloud, meta.obj_to_dict(standard_fake_server))
-        self.assertEquals('volume1', hostvars['volumes'][0]['id'])
-        self.assertEquals('/dev/sda0', hostvars['volumes'][0]['device'])
+        self.assertEqual('volume1', hostvars['volumes'][0]['id'])
+        self.assertEqual('/dev/sda0', hostvars['volumes'][0]['device'])
 
     def test_has_no_volume_service(self):
         fake_cloud = FakeCloud()
         fake_cloud.service_val = False
         hostvars = meta.get_hostvars_from_server(
             fake_cloud, meta.obj_to_dict(standard_fake_server))
-        self.assertEquals([], hostvars['volumes'])
+        self.assertEqual([], hostvars['volumes'])
 
     def test_unknown_volume_exception(self):
         mock_cloud = mock.MagicMock()
@@ -646,7 +923,7 @@ class TestMeta(base.TestCase):
         self.assertNotIn('get_flavor_name', cloud_dict)
         self.assertNotIn('server', cloud_dict)
         self.assertTrue(hasattr(cloud_dict, 'name'))
-        self.assertEquals(cloud_dict.name, cloud_dict['name'])
+        self.assertEqual(cloud_dict.name, cloud_dict['name'])
 
     def test_obj_to_dict_subclass(self):
         class FakeObjDict(dict):
@@ -655,8 +932,8 @@ class TestMeta(base.TestCase):
         obj_dict = meta.obj_to_dict(obj)
         self.assertIn('additional', obj_dict)
         self.assertIn('foo', obj_dict)
-        self.assertEquals(obj_dict['additional'], 1)
-        self.assertEquals(obj_dict['foo'], 'bar')
+        self.assertEqual(obj_dict['additional'], 1)
+        self.assertEqual(obj_dict['foo'], 'bar')
 
     def test_warlock_to_dict(self):
         schema = {
@@ -675,4 +952,4 @@ class TestMeta(base.TestCase):
         self.assertNotIn('_unused', test_dict)
         self.assertEqual('test-image', test_dict['name'])
         self.assertTrue(hasattr(test_dict, 'name'))
-        self.assertEquals(test_dict.name, test_dict['name'])
+        self.assertEqual(test_dict.name, test_dict['name'])
