@@ -371,6 +371,29 @@ class TestShade(base.TestCase):
                                  host_routes=routes)
         self.assertTrue(mock_client.create_subnet.called)
 
+    @mock.patch.object(shade.OpenStackCloud, 'search_networks')
+    @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
+    def test_create_subnet_string_ip_version(self, mock_client, mock_search):
+        '''Allow ip_version as a string'''
+        net1 = dict(id='123', name='donald')
+        mock_search.return_value = [net1]
+        self.cloud.create_subnet('donald', '192.168.199.0/24', ip_version='4')
+        self.assertTrue(mock_client.create_subnet.called)
+
+    @mock.patch.object(shade.OpenStackCloud, 'search_networks')
+    @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
+    def test_create_subnet_bad_ip_version(self, mock_client, mock_search):
+        '''String ip_versions must be convertable to int'''
+        net1 = dict(id='123', name='donald')
+        mock_search.return_value = [net1]
+
+        with testtools.ExpectedException(
+                exc.OpenStackCloudException,
+                "ip_version must be an integer"
+        ):
+            self.cloud.create_subnet('donald', '192.168.199.0/24',
+                                     ip_version='4x')
+
     @mock.patch.object(shade.OpenStackCloud, 'search_networks')
     @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
     def test_create_subnet_without_gateway_ip(self, mock_client, mock_search):
@@ -513,7 +536,7 @@ class TestShade(base.TestCase):
         mock_response.json.return_value = dict(extra_specs=[])
         mock_compute.get.return_value = mock_response
         flavor = self.cloud.get_flavor_by_ram(ram=150)
-        self.assertEquals(chocolate.id, flavor['id'])
+        self.assertEqual(chocolate.id, flavor['id'])
 
     @mock.patch.object(shade.OpenStackCloud, '_compute_client')
     @mock.patch.object(shade.OpenStackCloud, 'nova_client')
@@ -528,7 +551,7 @@ class TestShade(base.TestCase):
         mock_nova_client.flavors.list.return_value = [
             vanilla, chocolate, strawberry]
         flavor = self.cloud.get_flavor_by_ram(ram=150, include='strawberry')
-        self.assertEquals(strawberry.id, flavor['id'])
+        self.assertEqual(strawberry.id, flavor['id'])
 
     @mock.patch.object(shade.OpenStackCloud, 'nova_client')
     def test_get_flavor_by_ram_not_found(self, mock_nova_client):
@@ -547,9 +570,9 @@ class TestShade(base.TestCase):
         mock_response.json.return_value = dict(extra_specs=[])
         mock_compute.get.return_value = mock_response
         flavor1 = self.cloud.get_flavor('1')
-        self.assertEquals(vanilla.id, flavor1['id'])
+        self.assertEqual(vanilla.id, flavor1['id'])
         flavor2 = self.cloud.get_flavor(1)
-        self.assertEquals(vanilla.id, flavor2['id'])
+        self.assertEqual(vanilla.id, flavor2['id'])
 
     def test__neutron_exceptions_resource_not_found(self):
         with mock.patch.object(
@@ -596,9 +619,9 @@ class TestShade(base.TestCase):
 
         r = self.cloud.list_servers()
 
-        self.assertEquals(1, len(r))
-        self.assertEquals(1, mock_add_srv_int.call_count)
-        self.assertEquals('testserver', r[0]['name'])
+        self.assertEqual(1, len(r))
+        self.assertEqual(1, mock_add_srv_int.call_count)
+        self.assertEqual('testserver', r[0]['name'])
 
     @mock.patch.object(shade._tasks.ServerList, 'main')
     @mock.patch('shade.meta.get_hostvars_from_server')
@@ -619,10 +642,10 @@ class TestShade(base.TestCase):
 
         r = self.cloud.list_servers(detailed=True)
 
-        self.assertEquals(2, len(r))
-        self.assertEquals(len(r), mock_get_hostvars_from_server.call_count)
-        self.assertEquals('server1', r[0]['name'])
-        self.assertEquals('server2', r[1]['name'])
+        self.assertEqual(2, len(r))
+        self.assertEqual(len(r), mock_get_hostvars_from_server.call_count)
+        self.assertEqual('server1', r[0]['name'])
+        self.assertEqual('server2', r[1]['name'])
 
     def test_iterate_timeout_bad_wait(self):
         with testtools.ExpectedException(
